@@ -18,7 +18,6 @@
 #if !defined(ARMA_ALIEN_MEM_ALLOC_FUNCTION) || !defined(ARMA_ALIEN_MEM_FREE_FUNCTION)
 #error "ALIEN ALLOCATION FUNCTIONS SHOULD BE DEFINED FIRST"
 #endif
-  
 
 //! \addtogroup memory
 //! @{
@@ -28,7 +27,7 @@ class memory
   {
   public:
   
-  template<typename eT> inline arma_malloc static eT* acquire(const uword n_elem);
+  template<typename eT> arma_malloc inline static eT* acquire(const uword n_elem);
   
   template<typename eT> arma_inline static void release(eT* mem);
   
@@ -40,14 +39,14 @@ class memory
 
 
 template<typename eT>
-inline
 arma_malloc
+inline
 eT*
 memory::acquire(const uword n_elem)
   {
   if(n_elem == 0)  { return nullptr; }
   
-  arma_debug_check
+  arma_conform_check
     (
     ( size_t(n_elem) > (std::numeric_limits<size_t>::max() / sizeof(eT)) ),
     "arma::memory::acquire(): requested size is too large"
@@ -152,7 +151,7 @@ arma_inline
 bool
 memory::is_aligned(const eT* mem)
   {
-  #if (defined(ARMA_HAVE_ICC_ASSUME_ALIGNED) || defined(ARMA_HAVE_GCC_ASSUME_ALIGNED)) && !defined(ARMA_DONT_CHECK_ALIGNMENT)
+  #if (defined(ARMA_HAVE_GCC_ASSUME_ALIGNED) || defined(__cpp_lib_assume_aligned)) && !defined(ARMA_DONT_CHECK_ALIGNMENT)
     {
     return (sizeof(std::size_t) >= sizeof(eT*)) ? ((std::size_t(mem) & 0x0F) == 0) : false;
     }
@@ -172,30 +171,19 @@ arma_inline
 void
 memory::mark_as_aligned(eT*& mem)
   {
-  #if defined(ARMA_HAVE_ICC_ASSUME_ALIGNED)
-    {
-    __assume_aligned(mem, 16);
-    }
-  #elif defined(ARMA_HAVE_GCC_ASSUME_ALIGNED)
+  #if defined(ARMA_HAVE_GCC_ASSUME_ALIGNED)
     {
     mem = (eT*)__builtin_assume_aligned(mem, 16);
     }
+  #elif defined(__cpp_lib_assume_aligned)
+    {
+    mem = (eT*)std::assume_aligned<16>(mem);
+    }
   #else
     {
     arma_ignore(mem);
     }
   #endif
-  
-  // TODO: MSVC?  __assume( (mem & 0x0F) == 0 );
-  //
-  // http://comments.gmane.org/gmane.comp.gcc.patches/239430
-  // GCC __builtin_assume_aligned is similar to ICC's __assume_aligned,
-  // so for lvalue first argument ICC's __assume_aligned can be emulated using
-  // #define __assume_aligned(lvalueptr, align) lvalueptr = __builtin_assume_aligned (lvalueptr, align) 
-  //
-  // http://www.inf.ethz.ch/personal/markusp/teaching/263-2300-ETH-spring11/slides/class19.pdf
-  // http://software.intel.com/sites/products/documentation/hpc/composerxe/en-us/cpp/lin/index.htm
-  // http://d3f8ykwhia686p.cloudfront.net/1live/intel/CompilerAutovectorizationGuide.pdf
   }
 
 
@@ -205,14 +193,14 @@ arma_inline
 void
 memory::mark_as_aligned(const eT*& mem)
   {
-  #if defined(ARMA_HAVE_ICC_ASSUME_ALIGNED)
-    {
-    __assume_aligned(mem, 16);
-    }
-  #elif defined(ARMA_HAVE_GCC_ASSUME_ALIGNED)
+  #if defined(ARMA_HAVE_GCC_ASSUME_ALIGNED)
     {
     mem = (const eT*)__builtin_assume_aligned(mem, 16);
     }
+  #elif defined(__cpp_lib_assume_aligned)
+    {
+    mem = (const eT*)std::assume_aligned<16>(mem);
+    }
   #else
     {
     arma_ignore(mem);
