@@ -2,7 +2,10 @@ library(testthat)
  Sys.setenv('OMP_THREAD_LIMIT'=2)
  library(rlibkriging)
 
-kernel="gauss"
+##library(rlibkriging, lib.loc="bindings/R/Rlibs")
+##library(testthat)
+#kernel="gauss"
+
 for (kernel in c("exp","matern3_2","matern5_2","gauss")) {
   context(paste0("Check LogLikelihood for kernel ",kernel))
   
@@ -18,29 +21,29 @@ for (kernel in c("exp","matern3_2","matern5_2","gauss")) {
   alpha0 = k@covariance@sd2/(k@covariance@sd2+k@covariance@nugget)
   ll_theta = function(theta) DiceKriging::logLikFun(c(theta,alpha0),k)
   plot(Vectorize(ll_theta),ylab="LL",xlab="theta",xlim=c(0.01,1))
-  for (x in seq(0.01,1,,21)){
+  for (x in seq(0.01,1,,5)){
     envx = new.env()
     llx = DiceKriging::logLikFun(c(x,alpha0),k,envx)
     gllx = DiceKriging::logLikGrad(c(x,alpha0),k,envx)[1,]
     arrows(x,llx,x+.1,llx+.1*gllx)
   }
   
-  #library(rlibkriging)
+  ##library(rlibkriging)
   r <- NuggetKriging(y, X, kernel, parameters=list(nugget=0,is_nugget_estim=TRUE))
   ll2_theta = function(theta) logLikelihoodFun(r,c(theta,alpha0))$logLikelihood
   # second arg is alpha=1 for nugget=0
   # plot(Vectorize(ll2),col='red'), add=T) 
-  for (x in seq(0.01,1,,21)){
+  for (x in seq(0.01,1,,5)){
     envx = new.env()
     ll2x = logLikelihoodFun(r,c(x,alpha0))$logLikelihood
-    gll2x = logLikelihoodFun(r,c(x,alpha0),grad = T)$logLikelihoodGrad[,1]
+    gll2x = logLikelihoodFun(r,c(x,alpha0),return_grad = T)$logLikelihoodGrad[,1]
     arrows(x,ll2x,x+.1,ll2x+.1*gll2x,col='red')
   }
   
   theta0 = k@covariance@range.val
   ll_alpha = function(alpha) DiceKriging::logLikFun(c(theta0,alpha),k)
   plot(Vectorize(ll_alpha),ylab="LL",xlab="alpha",xlim=c(0.01,1))
-  for (x in seq(0.01,1,,21)){
+  for (x in seq(0.01,1,,5)){
     envx = new.env()
     llx = DiceKriging::logLikFun(c(theta0,x),k,envx)
     gllx = DiceKriging::logLikGrad(c(theta0,x),k,envx)[2,]
@@ -48,10 +51,10 @@ for (kernel in c("exp","matern3_2","matern5_2","gauss")) {
   }
   ll2_alpha = function(alpha) logLikelihoodFun(r,c(theta0,alpha))$logLikelihood
   #plot(Vectorize(ll2_alpha),col='red',add=T)
-  for (x in seq(0.01,1,,21)){
+  for (x in seq(0.01,1,,5)){
     envx = new.env()
     ll2x = logLikelihoodFun(r,c(theta0,x))$logLikelihood
-    gll2x = logLikelihoodFun(r,c(theta0,x),grad = T)$logLikelihoodGrad[,2]
+    gll2x = logLikelihoodFun(r,c(theta0,x),return_grad = T)$logLikelihoodGrad[,2]
     arrows(x,ll2x,x+.1,ll2x+.1*gll2x,col='red')
   }
 
@@ -67,14 +70,14 @@ for (kernel in c("exp","matern3_2","matern5_2","gauss")) {
   
   test_that(desc="logLik Grad is just good /alpha", 
             expect_equal(
-              logLikelihoodFun(r,c(theta0,x),grad=T)$logLikelihoodGrad[,2]
+              logLikelihoodFun(r,c(theta0,x),return_grad=T)$logLikelihoodGrad[,2]
               ,
               -(logLikelihoodFun(r,c(theta0,x-1e-5))$logLikelihood[1]-logLikelihoodFun(r,c(theta0,x))$logLikelihood[1])/1e-5,
               ,tolerance= 1e-5))
               
   test_that(desc="logLik Grad is the same that DiceKriging one /alpha", 
             expect_equal(
-              logLikelihoodFun(r,c(theta0,x),grad=T)$logLikelihoodGrad[,2]
+              logLikelihoodFun(r,c(theta0,x),return_grad=T)$logLikelihoodGrad[,2]
               ,
               DiceKriging::logLikGrad(c(theta0,x),k,xenv)[2,]
               ,tolerance= precision))
@@ -89,14 +92,14 @@ for (kernel in c("exp","matern3_2","matern5_2","gauss")) {
 
   test_that(desc="logLik Grad is just good /theta", 
             expect_equal(
-              logLikelihoodFun(r,c(x,alpha0),grad=T)$logLikelihoodGrad[,1]
+              logLikelihoodFun(r,c(x,alpha0),return_grad=T)$logLikelihoodGrad[,1]
               ,
               (logLikelihoodFun(r,c(x+1e-5,alpha0))$logLikelihood[1]-logLikelihoodFun(r,c(x,alpha0))$logLikelihood[1])/1e-5
               ,tolerance= 1e-3))
 
   test_that(desc="logLik Grad is the same that DiceKriging one /theta", 
             expect_equal(
-              logLikelihoodFun(r,c(x,alpha0),grad=T)$logLikelihoodGrad[,1]
+              logLikelihoodFun(r,c(x,alpha0),return_grad=T)$logLikelihoodGrad[,1]
               ,
               DiceKriging::logLikGrad(c(x,alpha0),k,xenv)[1,]
               ,tolerance= precision))
@@ -112,7 +115,7 @@ for (kernel in c("matern3_2","matern5_2","gauss","exp")) {
   context(paste0("Check LogLikelihood for kernel ",kernel))
   
   f <- function(X) apply(X, 1, function(x) prod(sin((x-.5)^2)))
-  n <- 100
+  n <- 10
   set.seed(123)
   X <- cbind(runif(n),runif(n),runif(n))
   y <- f(X)
@@ -137,7 +140,7 @@ for (kernel in c("matern3_2","matern5_2","gauss","exp")) {
   
   test_that(desc="logLik Grad is the same that DiceKriging one", 
             expect_equal(
-              logLikelihoodFun(r,x,grad=T)$logLikelihoodGrad[1,]
+              logLikelihoodFun(r,x,return_grad=T)$logLikelihoodGrad[1,]
               ,
               t(DiceKriging::logLikGrad(x,k,xenv))[1,]
               ,tolerance= precision))
@@ -145,7 +148,7 @@ for (kernel in c("matern3_2","matern5_2","gauss","exp")) {
   eps=0.000001
   test_that(desc="logLik Grad is just good", 
             expect_equal(
-              -logLikelihoodFun(r,x,grad=T)$logLikelihoodGrad[1,]
+              -logLikelihoodFun(r,x,return_grad=T)$logLikelihoodGrad[1,]
               ,
               c( # finite-diff grad
                 (logLikelihoodFun(r,x-c(eps,0,0,0))$logLikelihood[1]-logLikelihoodFun(r,x)$logLikelihood[1])/eps,
